import { world, system} from '@minecraft/server';
const colorData = {
    red: [166, 26, 18],
    white: [255, 255, 255],
    black: [0, 0, 0],
    gray: [76, 76, 76],
    light_gray: [179, 179, 179],
    brown: [116, 67, 29],
    orange: [247, 106, 0],
    yellow: [255, 201, 10],
    lime: [105, 191, 9],
    green: [83, 113, 18],
    cyan: [4, 142, 151],
    light_blue: [33, 173, 224],
    blue: [36, 41, 170],
    purple: [117, 23, 178],
    magenta: [191, 48, 181],
    pink: [229, 118, 153]
};
world.afterEvents.playerPlaceBlock.subscribe((eventData) => {
    let block = eventData.block;
    if (block.typeId === "minecraft:carved_pumpkin" && block.below().typeId.includes("wool") && block.below(2).typeId === "minecraft:tuff") {
        let color = block.below().typeId.slice(0, -5).slice(10).replace(/ /g, "_");
        let tuffGolem = block.dimension.spawnEntity("forgotten:tuff_golem", block.location);
        tuffGolem.setProperty("forgotten:red", colorData[color][0]/255);
        tuffGolem.setProperty("forgotten:green", colorData[color][1]/255);
        tuffGolem.setProperty("forgotten:blue", colorData[color][2]/255);
        block.dimension.fillBlocks(block.location, block.below(2).location, "minecraft:air");
    };
});
function setState(entity, data) {
    for (let i = 0; i < 7; i++) {
        entity.setProperty(`forgotten:state_${i}`, data[i]);
    };
};
function checkPlayerAmount(player) {
    return player.getComponent('inventory').container.getItem(player.selectedSlot)?.amount || 0;
};
world.beforeEvents.playerInteractWithEntity.subscribe((eventData) => {
    let entity = eventData.target;
    if (eventData.player.isSneaking && entity.typeId === "forgotten:tuff_golem") {
        eventData.cancel = true;
        system.run(() => {
            if (entity.getProperty("forgotten:sleeping")) {
                entity.applyImpulse({x: 0, y: 0.3, z: 0});
                entity.setRotation({x:0, y: Math.round(entity.getRotation().y + 10)});
            } else {
                entity.triggerEvent("sleep");
            }
        });
    };
});
world.afterEvents.playerInteractWithEntity.subscribe((eventData) => {
    let player = eventData.player;
    let entity = eventData.target;
    let item = eventData.itemStack;
    if (entity.typeId === "forgotten:tuff_golem" && item !== undefined && !player.isSneaking) {
        if (checkPlayerAmount(player) === item.amount) return;
        let name = item.typeId.slice(10);
        let uniqueNameBlock = ["podzol", "mob_spawner", "dragon_egg", "dispenser", "target", "dropper", "observer", "daylight_detector", "loom", "tnt", "mycelium", "gravel", "granite", "bedrock", "end_portal_frame", "redstone_lamp", "sea_lantern", "beacon", "grindstone", "smoker", "jukebox", "respawn_anchor", "lectern", "composter", "barrel", "chorus_flower", "end_stone", "chorus_plant", "andesite", "monster_egg", "calcite","mangrove_roots", "budding_amethyst", "blackstone", "diorite", "grass", "grass_path", "shroomlight", "netherrack", "lodestone", "scaffolding", "ancient_debris", "stone", "soul_soil", "soul_sand", "sponge"];
        if (name.includes("axe") || name.includes("hoe") || name.includes("pickaxe") || name.includes("shovel") || name.includes("sword")) {
            setState(entity, [-45, 90, 0, 0, 0, 0, 0.8]);
        } else if (name === "bow") {
            setState(entity, [10, 0, 90, 0, 2, 2, 0.8]);
        } else if (name === "banner") {
            setState(entity, [-5, 170, -12, 5, -2, -5, 1.75]);
        } else if (name === "crossbow") {
            setState(entity, [-10, 90, 0, 3.5, -2, 1, 0.8]);
        } else if (name === "shield") {
            setState(entity, [-10, 0, 90, 0, -2, 1, 0.8]);
        } else if (name === "trident") {
            setState(entity, [-10, 0, 90, 2, 1.75, 1, 0.85]);
        } else if (name === "fishing_rod" || name === "carrot_on_a_stick" || name === "warped_fungus_on_a_stick") {
            setState(entity, [-10, 0, -90, 5, 1.75, 2, 0.85]);
        } else if (name === "door") {
            setState(entity, [0, -10, -10, -1.5, -1, 0, 1.2]);
        } else if (name === "iron_bars") {
            setState(entity, [0, -12, -15, -1, -0.2, 0, 1]);
        } else if (name === "decorated_pot") {
            setState(entity, [50, -45, 0, -7, 4.5, 7, 1.5]);
        } else if (name.includes("button")) {
            setState(entity, [57.5, 45, 0, 2, 4, 8, 1.7]);
        } else if (name.includes("wall")) {
            setState(entity, [57.5, -45, 0, -7, 1, 0, 1]);
        } else if (name.includes("skull")) {
            setState(entity, [57.5, -135, 0, -4.5, 3.5, -8.5, 1.7]);
        } else if (name === "conduit") {
            setState(entity, [57.5, -45, 0, -7, 5, 4, 1.8]);
        } else if (name.includes("carpet")) {
            setState(entity, [57.5, -135, 0, -4, 0, -3, 1.2]);
        } else if (name === "snow_layer") {
            setState(entity, [57.5, -135, 0, -4, 3, -5, 1.2]);
        } else if ( uniqueNameBlock.includes(name) || name.includes("slab") || name.includes("piston") || name.includes("furnace") || (name.includes("chest") && !name.includes("chestplate")) || name.includes("table") || name.includes("bookshelf") ||  name.includes("suspicious") || (name.includes("sculk") && name !== "sculk_vein") || name.includes("obsidian") || name.includes("leave") || name.includes("froglight") || name.includes("azalea") || name.includes("tuff") || name.includes("leave") || name.includes("dirt") || name.includes("ice") || name.includes("bee") || name.includes("log") || name.includes("wood") || name.includes("hyphae") || name.includes("stem") || name.includes("shulker") || name.includes("polished") || name.includes("nylium") || name.includes("basalt") || name.includes("mud") || name.includes("ore") || (name.includes("clay") && !name.includes("ball")) || name.includes("concrete") || name.includes("wool") || name.includes("terracotta") || (name.includes("prismarine") && !name.includes("shard") && !name.includes("crystal")) || name.includes("smooth") || name.includes("sandstone") || name.includes("cobblestone") || (name.includes("pumpkin") && !name.includes("seed") && !name.includes("pie")) || name.includes("stonebrick") || name.includes("glass") || name.includes("trapdoor") || name.includes("gate") || name.includes("stairs") || name.includes("planks") || (name.includes("fence") && !name.includes("gate")) || name.includes("bricks") || name.includes("deepslate") || name.includes("block") || name.includes("tiles") || (name.includes("copper") && !name.includes("raw")) ) {
            setState(entity, [57.5, -45, 0, -4.75, 4.5, 4, 1.2]);
        } else {
            setState(entity, [15, -10, -16, -1, -0.5, 1.5, 1]);
        }
    };
});

